View source: R/assign_guild_ants.R
| assign_guild_ants | R Documentation |
Classifies ants into functional guilds using four different ecological databases.
assign_guild_ants(
comm,
verbose = TRUE,
plot = TRUE,
validate = TRUE,
delay = 0.5
)
comm |
A community matrix where species are columns and samples are rows. |
verbose |
Logical; if |
plot |
Logical; if |
validate |
Logical; if |
delay |
Numeric; seconds to wait between GBIF API calls when |
Invisibly returns a list with two elements:
table |
A data frame containing species, abundance, percentage, and guild assignments from each system. |
plots |
A list of four ggplot2 objects, one for each guild classification system. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.