View source: R/check_endemic_atlantic_ants.R
| check_endemic_atlantic_ants | R Documentation |
Checks a community matrix for ant species endemic to the Brazilian Atlantic Forest based on Silva et al. (2025).
check_endemic_atlantic_ants(
comm,
verbose = TRUE,
plot = TRUE,
plot_type = c("status", "species"),
validate = TRUE,
delay = 0.5
)
comm |
A community matrix where species are columns and samples are rows. |
verbose |
Logical; if |
plot |
Logical; if |
plot_type |
Character; type of plot to display. |
validate |
Logical; if |
delay |
Numeric; seconds to wait between GBIF API calls when |
Invisibly returns a list with two elements:
table |
A data frame containing endemic species detected, with columns species, abundance, and percentage. |
plot |
A ggplot2 object. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.